@@ -34,7 +34,7 @@ pub struct Endpoint {
 impl Endpoint {
     /// Converts Endpoint to resource. Does not save it.
     pub fn to_resource(&self, store: &impl Storelike) -> AtomicResult<Resource> {
-        let subject = format!("{}{}", store.get_base_url(), self.path);
+        let subject = format!("{}{}", store.get_server_url(), self.path);
         let mut resource = Resource::new(subject);
         resource.set_propval_string(urls::DESCRIPTION.into(), &self.description, store)?;
         resource.set_propval_string(urls::SHORTNAME.into(), &self.shortname, store)?;
