@@ -4,6 +4,7 @@ use crate::{
 };
 
 /// If there is a valid Agent in the correct query param, and the invite is valid, update the rights and respond with a redirect to the target resource
+#[tracing::instrument(skip(store, query_params))]
 pub fn construct_invite_redirect(
     store: &impl Storelike,
     query_params: url::form_urlencoded::Parse,
@@ -56,8 +57,7 @@ pub fn construct_invite_redirect(
         })?
         .to_string();
 
-    println!("Invite resource before: {:?}", invite_resource);
-
+    // If any usages left value is present, make sure it's a positive number and decrement it by 1.
     if let Ok(usages_left) = invite_resource.get(urls::USAGES_LEFT) {
         let num = usages_left.to_int()?;
         if num == 0 {
@@ -73,10 +73,16 @@ pub fn construct_invite_redirect(
             .map_err(|e| format!("Unable to save updated Invite. {}", e))?;
     }
 
-    println!("Invite resource after: {:?}", invite_resource);
+    if let Ok(expires) = invite_resource.get(urls::EXPIRES_AT) {
+        if expires.to_int()? > crate::datetime_helpers::now() {
+            return Err("Invite is no longer valid".into());
+        }
+    }
 
-    // TODO: implement rights check
-    // check_if_invite_is_valid(invite_resource)?;
+    // Make sure the creator of the invite is still allowed to Write the target
+    let invite_creator =
+        crate::plugins::versioning::get_initial_commit_for_resource(target, store)?.signer;
+    crate::hierarchy::check_write(store, &store.get_resource(target)?, &invite_creator)?;
 
     add_rights(&agent, target, write, store)?;
     if write {
@@ -84,6 +90,7 @@ pub fn construct_invite_redirect(
         add_rights(&agent, target, false, store)?;
     }
 
+    // Construct the Redirect Resource, which might provide the Client with a Subject for his Agent.
     let mut redirect = Resource::new_instance(urls::REDIRECT, store)?;
     redirect.set_propval(
         urls::DESTINATION.into(),
@@ -104,6 +111,7 @@ pub fn construct_invite_redirect(
 /// Overwrites the target resource to include the new rights.
 /// Checks if the Agent has a valid URL.
 /// Will not throw an error if the Agent already has the rights.
+#[tracing::instrument(skip(store))]
 pub fn add_rights(
     agent: &str,
     target: &str,
