@@ -6,10 +6,11 @@ pub fn path_endpoint() -> Endpoint {
         params: [urls::PATH.to_string()].into(),
         description: "An Atomic Path is a string that starts with the URL of some Atomic Resource, followed by one or multiple other Property URLs or Property Shortnames. It resolves to one specific Resource or Value. At this moment, Values are not yet supported.".to_string(),
         shortname: "path".to_string(),
-        handle: handle_path_request,
+        handle: Some(handle_path_request),
     }
 }
 
+#[tracing::instrument(skip(store))]
 fn handle_path_request(
     url: url::Url,
     store: &impl Storelike,
