@@ -12,6 +12,7 @@ pub const DRIVE: &str = "https://atomicdata.dev/classes/Drive";
 pub const INVITE: &str = "https://atomicdata.dev/classes/Invite";
 pub const REDIRECT: &str = "https://atomicdata.dev/classes/Redirect";
 pub const ATOM: &str = "https://atomicdata.dev/classes/Atom";
+pub const FILE: &str = "https://atomicdata.dev/classes/File";
 
 // Properties
 pub const SHORTNAME: &str = "https://atomicdata.dev/properties/shortname";
@@ -76,11 +77,19 @@ pub const WRITE_BOOL: &str = "https://atomicdata.dev/properties/invite/write";
 pub const INVITE_PUBKEY: &str = "https://atomicdata.dev/properties/invite/publicKey";
 pub const INVITE_AGENT: &str = "https://atomicdata.dev/properties/invite/agent";
 pub const REDIRECT_AGENT: &str = "https://atomicdata.dev/properties/invite/redirectAgent";
+pub const EXPIRES_AT: &str = "https://atomicdata.dev/properties/invite/expiresAt";
 // ... for Atoms
 pub const ATOM_SUBJECT: &str = "https://atomicdata.dev/properties/atom/subject";
 pub const ATOM_PROPERTY: &str = "https://atomicdata.dev/properties/atom/property";
 pub const ATOM_VALUE: &str = "https://atomicdata.dev/properties/atom/value";
-
+// ... for Files
+pub const CHECKSUM: &str = "https://atomicdata.dev/properties/checksum";
+pub const FILENAME: &str = "https://atomicdata.dev/properties/filename";
+pub const FILESIZE: &str = "https://atomicdata.dev/properties/filesize";
+pub const MIMETYPE: &str = "https://atomicdata.dev/properties/mimetype";
+pub const INTERNAL_ID: &str = "https://atomicdata.dev/properties/internalId";
+pub const DOWNLOAD_URL: &str = "https://atomicdata.dev/properties/downloadURL";
+pub const ATTACHMENTS: &str = "https://atomicdata.dev/properties/attachments";
 // Datatypes
 pub const STRING: &str = "https://atomicdata.dev/datatypes/string";
 pub const MARKDOWN: &str = "https://atomicdata.dev/datatypes/markdown";
